@@ -1,21 +1,21 @@
 /*
- * Copyright (c) 2016-2017 Digital Bazaar, Inc. All rights reserved.
+ * Copyright (c) 2016-2021 Digital Bazaar, Inc. All rights reserved.
  */
 'use strict';
 
-const util = require('./util');
-
 module.exports = class IdentifierIssuer {
   /**
    * Creates a new IdentifierIssuer. A IdentifierIssuer issues unique
    * identifiers, keeping track of any previously issued identifiers.
    *
    * @param prefix the prefix to use ('<prefix><counter>').
+   * @param existing an existing Map to use.
+   * @param counter the counter to use.
    */
-  constructor(prefix) {
+  constructor(prefix, existing = new Map(), counter = 0) {
     this.prefix = prefix;
-    this.counter = 0;
-    this.existing = {};
+    this._existing = existing;
+    this.counter = counter;
   }
 
   /**
@@ -24,10 +24,8 @@ module.exports = class IdentifierIssuer {
    * @return a copy of this IdentifierIssuer.
    */
   clone() {
-    const copy = new IdentifierIssuer(this.prefix);
-    copy.counter = this.counter;
-    copy.existing = util.clone(this.existing);
-    return copy;
+    const {prefix, _existing, counter} = this;
+    return new IdentifierIssuer(prefix, new Map(_existing), counter);
   }
 
   /**
@@ -40,17 +38,18 @@ module.exports = class IdentifierIssuer {
    */
   getId(old) {
     // return existing old identifier
-    if(old && old in this.existing) {
-      return this.existing[old];
+    const existing = old && this._existing.get(old);
+    if(existing) {
+      return existing;
     }
 
     // get next identifier
     const identifier = this.prefix + this.counter;
-    this.counter += 1;
+    this.counter++;
 
     // save mapping
     if(old) {
-      this.existing[old] = identifier;
+      this._existing.set(old, identifier);
     }
 
     return identifier;
@@ -66,6 +65,16 @@ module.exports = class IdentifierIssuer {
    *   false if not.
    */
   hasId(old) {
-    return (old in this.existing);
+    return this._existing.has(old);
+  }
+
+  /**
+   * Returns all of the IDs that have been issued new IDs in the order in
+   * which they were issued new IDs.
+   *
+   * @return the list of old IDs that has been issued new IDs in order.
+   */
+  getOldIds() {
+    return [...this._existing.keys()];
   }
 };
