@@ -1,5 +1,5 @@
-/*
- * Copyright (c) 2016-2021 Digital Bazaar, Inc. All rights reserved.
+/*!
+ * Copyright (c) 2016-2022 Digital Bazaar, Inc. All rights reserved.
  */
 'use strict';
 
@@ -7,8 +7,6 @@ require('setimmediate');
 
 const crypto = self.crypto || self.msCrypto;
 
-// TODO: synchronous version no longer supported in browser
-
 module.exports = class MessageDigest {
   /**
    * Creates a new MessageDigest.
@@ -26,7 +24,7 @@ module.exports = class MessageDigest {
     } else if(algorithm === 'sha1') {
       this.algorithm = {name: 'SHA-1'};
     } else {
-      throw new Error(`Unsupport algorithm "${algorithm}".`);
+      throw new Error(`Unsupported algorithm "${algorithm}".`);
     }
     this._content = '';
   }
