@@ -13,11 +13,12 @@ const NQuads = require('./NQuads');
 module.exports = class URDNA2015Sync {
   constructor({
     createMessageDigest = () => new MessageDigest('sha256'),
+    canonicalIdMap = new Map(),
     maxDeepIterations = Infinity
   } = {}) {
     this.name = 'URDNA2015';
     this.blankNodeInfo = new Map();
-    this.canonicalIssuer = new IdentifierIssuer('_:c14n');
+    this.canonicalIssuer = new IdentifierIssuer('_:c14n', canonicalIdMap);
     this.createMessageDigest = createMessageDigest;
     this.maxDeepIterations = maxDeepIterations;
     this.quads = null;
