@@ -1,15 +1,16 @@
-/*
+/*!
  * Copyright (c) 2016-2021 Digital Bazaar, Inc. All rights reserved.
  */
 'use strict';
 
+const MessageDigest = require('./MessageDigest');
 const URDNA2015Sync = require('./URDNA2015Sync');
 
 module.exports = class URDNA2012Sync extends URDNA2015Sync {
   constructor() {
     super();
     this.name = 'URGNA2012';
-    this.hashAlgorithm = 'sha1';
+    this.createMessageDigest = () => new MessageDigest('sha1');
   }
 
   // helper for modifying component during Hash First Degree Quads
